@@ -21,7 +21,7 @@ def Help():
                  moon_icon: str = 'weather-night', main_color: str = 'Blue''')
 
 
-def Spec(name: str, filename: str, icon: str, path: str = os.getcwd()):
+def Spec(name: str, filename: str = 'main.py', icon: str = '', path: str = os.getcwd()):
 
     path = path.replace("\\", r"\\")
 
@@ -127,6 +127,7 @@ class Kivy4(MDApp):
         self.settings_cls = ContentPanel
         self.title = self.app_name
         Window.bind(on_request_close=lambda x: self.on_request_close(self.disable_x))
+        Window.bind(on_drop_file=self.on_drop_file)
 
         if self.run_at_build:
             self.Build()
@@ -255,7 +256,7 @@ class Kivy4(MDApp):
 
     def getToolbar(self, properties: list):
         if properties == True:
-            properties = ['toolbar', self.app_name, '[]', '[[app.dark_mode_icon, lambda x: self.reverseDarkMode()]]']
+            properties = ['toolbar', self.app_name, '[]', '[[app.dark_mode_icon, lambda x: app.reverseDarkMode()]]']
 
         Id, title, right_icons, left_icons = properties
 
@@ -294,4 +295,8 @@ Screen:
 
 <Btn@MDFillRoundFlatIconButton>:
     text: ""
-'''
\ No newline at end of file
+'''
+
+    @staticmethod
+    def on_drop_file(_, path, x, y):
+        print(path, x, y)
\ No newline at end of file
